package com.muyu.product.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.product.domain.GroupOrder;
import com.muyu.product.domain.req.GroupOrderQueryReq;
import com.muyu.product.domain.req.GroupOrderSaveReq;
import com.muyu.product.domain.req.GroupOrderEditReq;
import com.muyu.product.service.GroupOrderService;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 拼团订单Controller
 *
 * @author DongZeLiang
 * @date 2024-11-14
 */
@Api(tags = "拼团订单")
@RestController
@RequestMapping("/GroupOrder")
public class GroupOrderController extends BaseController {
    @Autowired
    private GroupOrderService groupOrderService;

    /**
     * 查询拼团订单列表
     */
    @ApiOperation("获取拼团订单列表")
    @RequiresPermissions("product:GroupOrder:list")
    @GetMapping("/list")
    public Result<TableDataInfo<GroupOrder>> list(GroupOrderQueryReq groupOrderQueryReq) {
        startPage();
        List<GroupOrder> list = groupOrderService.list(GroupOrder.queryBuild(groupOrderQueryReq));
        return getDataTable(list);
    }

    /**
     * 导出拼团订单列表
     */
    @ApiOperation("导出拼团订单列表")
    @RequiresPermissions("product:GroupOrder:export")
    @Log(title = "拼团订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GroupOrder groupOrder) {
        List<GroupOrder> list = groupOrderService.list(groupOrder);
        ExcelUtil<GroupOrder> util = new ExcelUtil<GroupOrder>(GroupOrder.class);
        util.exportExcel(response, list, "拼团订单数据");
    }

    /**
     * 获取拼团订单详细信息
     */
    @ApiOperation("获取拼团订单详细信息")
    @RequiresPermissions("product:GroupOrder:query")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<GroupOrder> getInfo(@PathVariable("id") Long id) {
        return Result.success(groupOrderService.getById(id));
    }

    /**
     * 新增拼团订单
     */
    @RequiresPermissions("product:GroupOrder:add")
    @Log(title = "拼团订单", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增拼团订单")
    public Result<String> add(@RequestBody GroupOrderSaveReq groupOrderSaveReq) {
        return toAjax(groupOrderService.save(GroupOrder.saveBuild(groupOrderSaveReq)));
    }

    /**
     * 修改拼团订单
     */
    @RequiresPermissions("product:GroupOrder:edit")
    @Log(title = "拼团订单", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改拼团订单")
    public Result<String> edit(@PathVariable Long id, @RequestBody GroupOrderEditReq groupOrderEditReq) {
        return toAjax(groupOrderService.updateById(GroupOrder.editBuild(id,groupOrderEditReq)));
    }

    /**
     * 删除拼团订单
     */
    @RequiresPermissions("product:GroupOrder:remove")
    @Log(title = "拼团订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除拼团订单")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        return toAjax(groupOrderService.removeBatchByIds(ids));
    }
}
